agentle.agents.agent
====================

.. automodule:: agentle.agents.agent

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
      alru_cache
      asynccontextmanager
      cast
      contextmanager
      dedent
      file_parser_default_factory
      get_default_suspension_manager
      is_module_available
      override
      run_sync
   
   .. rubric:: Classes

   .. autosummary::
   
      Agent
      AgentConfig
      AgentConfigDict
      AgentRunOutput
      AgentSkill
      AgentToStreamlit
      Any
      AssistantMessage
      AsyncGenerator
      Authentication
      Awaitable
      BaseModel
      BytesIO
      Callable
      Capabilities
      ConfigDict
      Context
      ConversationStore
      DeveloperMessage
      DocumentCacheStore
      DocumentParser
      FilePart
      Generation
      GenerationProvider
      Generator
      GoogleGenerationProvider
      InMemoryDocumentCacheStore
      MCPServerProtocol
      Mapping
      Maybe
      MessageSequence
      MutableMapping
      MutableSequence
      ParsedFile
      Path
      Prompt
      RunState
      Sequence
      SpeechToTextProvider
      StaticKnowledge
      Step
      StringIO
      SuspensionManager
      TextPart
      Tool
      ToolExecutionSuggestion
      TraceParams
      UserMessage
      VectorStore
   
   .. rubric:: Exceptions

   .. autosummary::
   
      MaxToolCallsExceededError
      ToolSuspensionError
   